@@ -27,35 +27,26 @@ from its submodules.  These are:
 .. _Modelica: http://www.modelica.org/
 """
 __author__ = "Kevin Davies"
-__version__ = "0.1"
 __email__ = "kdavies4@gmail.com"
-# Copyright (c) 2010-2012, Kevin Davies
-# All rights reserved.
-#
-# Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions are met:
-#    * Redistributions of source code must retain the above copyright notice,
-#      this list of conditions and the following disclaimer.
-#    * Redistributions in binary form must reproduce the above copyright
-#      notice, this list of conditions and the following disclaimer in the
-#      documentation and/or other materials provided with the distribution.
-#    * Neither the name of the <organization> nor the names of its contributors
-#      may be used to endorse or promote products derived from this software
-#      without specific prior written permission.
+__copyright__ = "Copyright 2012, Georgia Tech Research Corporation"
+__license__ = "BSD-compatible (see LICENSE.txt)"
+__version__ = "0.4"
 
-# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
-# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
-# ARE DISCLAIMED. IN NO EVENT SHALL <COPYRIGHT HOLDER> BE LIABLE FOR ANY
-# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
-# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
-# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
-# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
-# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
+import sys
+
+
+# Check the Python version.
+major, minor1, minor2, s, tmp = sys.version_info
+if not (major == 2 and minor1 == 7):
+    raise ImportError('Currently, modelicares requires Python 2.7.')
+# TODO:  Add support for Python 3.x once wx supports it.
+
+
+# All functions and classes
 #__all__ = ['base', 'exps', 'linres', 'multi', 'simres', 'texunit']
 
+
 # Essential functions and classes
 #
 # These will be available directly from modelicares; others must be loaded from
@@ -64,7 +55,7 @@ from base import (add_arrows, add_hlines, add_vlines, animate, ArrowLine,
                  closeall, figure, load_csv, saveall, setup_subplots)
 from exps import (Experiment, gen_experiments, ParamDict, read_params,
                   run_models, write_params, write_script)
-from multi import multiload, multiplot
 from linres import LinRes
+from multi import multiload, multiplot
 from simres import SimRes
 from texunit import label_number, label_quantity, unit2tex
