@@ -1,8 +1,8 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-r"""Set up and help run Modelica_ simulation experiments.
+"""Set up and help run Modelica_ simulation experiments.
 
-This module suports two approaches for managing simulations.  The first is to
+This module supports two approaches for managing simulations.  The first is to
 create a Modelica_ script (using :meth:`write_script`) and run it within
 a Modelica_ environment (see "examples/ChuaCircuit.py"), which translates and
 simulates the models with the prescribed settings.  The second approach is to
@@ -21,55 +21,15 @@ parameter may have multiple possible values.  The dictionary is passed to the
 dictionary format), which combines the values of all the variables (by
 piecewise alignment or permutation) and returns a generator to step through the
 experiments.  Finally, the generator is passed to the :meth:`write_script` or
-:meth:`run_models` function (see first paragragh).
-
-.. Note::  The following examples are written for Linux.  On Windows\ :sup:`®`,
-   replace the path separators appropriately (change "/" to "\\").
+:meth:`run_models` function (see first paragraph).
 
 .. _Modelica: http://www.modelica.org/
 """
 __author__ = "Kevin Davies"
-__version__ = "0.1"
 __email__ = "kdavies4@gmail.com"
-# Copyright (c) 2010-2012, Kevin Davies
-# All rights reserved.
-#
-# Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions are met:
-#    * Redistributions of source code must retain the above copyright notice,
-#      this list of conditions and the following disclaimer.
-#    * Redistributions in binary form must reproduce the above copyright
-#      notice, this list of conditions and the following disclaimer in the
-#      documentation and/or other materials provided with the distribution.
-#    * Neither the name of the <organization> nor the names of its contributors
-#      may be used to endorse or promote products derived from this software
-#      without specific prior written permission.
-#    * This software is controlled under the jurisdiction of the United States
-#      Department of Commerce and subject to Export Administration Regulations.
-#      By downloading or using the Software, you are agreeing to comply with
-#      U. S. export controls.  Diversion contrary to law is prohibited.  The
-#      software cannot be exported or reexported to sanctioned countries that
-#      are controlled for Anti-Terrorism (15 CFR Part 738 Supplement 1) or to
-#      denied parties, http://beta-www.bis.doc.gov/index.php/policy-guidance/lists-of-parties-of-concern.
-#      EAR99 items cannot be exported or reexported to Iraq for a military
-#      purpose or to a military end-user (15 CFR Part 746.3).  Export and
-#      reexport include any release of technology to a foreign national within
-#      the United States.  Technology is released for export when it is
-#      available to foreign nationals for visual inspection, when technology is
-#      exchanged orally or when technology is made available by practice or
-#      application under the guidance of persons with knowledge of the
-#      technology.
-#
-# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
-# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
-# ARE DISCLAIMED. IN NO EVENT SHALL <COPYRIGHT HOLDER> BE LIABLE FOR ANY
-# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
-# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
-# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
-# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
-# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+__copyright__ = "Copyright 2012, Georgia Tech Research Corporation"
+__license__ = "BSD-compatible (see LICENSE.txt)"
+
 
 import os
 import re
@@ -146,7 +106,7 @@ def gen_experiments(models=None, params={}, args={}, permute = True):
        ...                       {'L.L': [16, 18, 20], 'C2.C': [80, 100, 120]},
        ...                       permute=False)
        >>> for experiment in doe:
-       ...     print experiment.model + str(experiment.params)
+       ...     print(experiment.model + str(experiment.params))
        Modelica.Electrical.Analog.Examples.ChuaCircuit(C2(C=80), L(L=16))
        Modelica.Electrical.Analog.Examples.ChuaCircuit(C2(C=100), L(L=18))
        Modelica.Electrical.Analog.Examples.ChuaCircuit(C2(C=120), L(L=20))
@@ -162,7 +122,7 @@ def gen_experiments(models=None, params={}, args={}, permute = True):
        ...                       {'L.L': [16, 18, 20], 'C2.C': [80, 100, 120]},
        ...                       permute=True)
        >>> for experiment in doe:
-       ...     print experiment.model + str(experiment.params)
+       ...     print(experiment.model + str(experiment.params))
        Modelica.Electrical.Analog.Examples.ChuaCircuit(C2(C=80), L(L=16))
        Modelica.Electrical.Analog.Examples.ChuaCircuit(C2(C=100), L(L=16))
        Modelica.Electrical.Analog.Examples.ChuaCircuit(C2(C=120), L(L=16))
@@ -183,7 +143,7 @@ def gen_experiments(models=None, params={}, args={}, permute = True):
        >>> params = dict(axis=dict(motor=dict(i_max=[5, 15],
        ...                                    Ra=dict(R=[200, 300]))))
        >>> for experiment in gen_experiments(models, params):
-       ...     print experiment.model + str(experiment.params)
+       ...     print(experiment.model + str(experiment.params))
        Modelica.Mechanics.MultiBody.Examples.Systems.RobotR3.oneAxis(axis(motor(i_max=5, Ra(R=200))))
        Modelica.Mechanics.MultiBody.Examples.Systems.RobotR3.oneAxis(axis(motor(i_max=15, Ra(R=200))))
        Modelica.Mechanics.MultiBody.Examples.Systems.RobotR3.oneAxis(axis(motor(i_max=5, Ra(R=300))))
@@ -381,7 +341,7 @@ def run_models(experiments=[(None, {}, {})],
 
          *model* may include the file path.  It is not necessary to include the
          extension (e.g., ".exe").   There must be a corresponding model
-         intialization file on the same path with the same base name and the
+         initialization file on the same path with the same base name and the
          extension ".in".  For Dymola\ :sup:`®`, the executable is the
          "dymosim" file (possibly renamed) and the initialization file is a
          renamed 'dsin.txt' file.
@@ -410,7 +370,7 @@ def run_models(experiments=[(None, {}, {})],
 
     There are no return values.
     """
-    raise NotImplementedError, "run_models() has not yet been implemented."
+    raise NotImplementedError("run_models() has not yet been implemented.")
     """
     **Examples:**
 import os
@@ -431,7 +391,7 @@ params = {'L.L': [18, 20],
 
 doe = gen_doe(params)
 for e in doe:
-   print str(e) + ' or ' + modifier(e)
+   print(str(e) + ' or ' + modifier(e))
 
 params.items()
 
@@ -574,7 +534,7 @@ def write_script(experiments=[(None, {}, {})], packages=[],
 
          Each may be a "\*.mo" file or a folder that contains a "package.mo"
          file.  The path may be absolute or relative to *working_dir*.  It may
-         be necessary to include in *packges* the file or folder that contains
+         be necessary to include in *packages* the file or folder that contains
          the model specified by the *model* subargument, but the Modelica
          Standard Library generally does not need to be included.
 
@@ -602,7 +562,7 @@ def write_script(experiments=[(None, {}, {})], packages=[],
           model name (*model*) without the full path.  '%i' may be included
           to indicate the simulation number in the sequence of experiments.
           '%x' may be included in the source or destination to represent '.exe'
-          if the operating system is Windows\ :sup:`®` and '' otherwise.
+          if the operating system is Windows and '' otherwise.
 
     If *command* is 'simulateModel' and the Modelica_ environment is
     Dymola\ :sup:`®`, then the following keywords may be used in *args*
@@ -644,7 +604,7 @@ def write_script(experiments=[(None, {}, {})], packages=[],
        >>> experiment = Experiment(model='Modelica.Electrical.Analog.Examples.ChuaCircuit',
        ...                         params={}, args=dict(stopTime=2500))
        >>> write_script(experiment, fname="examples/run-sims1.mos") # doctest: +ELLIPSIS
-       (['ChuaCircuit'], '.../examples')
+       (['ChuaCircuit'], '...examples')
 
     In "examples/run-sims1.mos":
 
@@ -678,7 +638,7 @@ def write_script(experiments=[(None, {}, {})], packages=[],
        ...             'C1.C': [8, 10],
        ...             'C2.C': [80, 100, 120]})
        >>> write_script(experiments, fname="examples/run-sims2.mos") # doctest: +ELLIPSIS
-       (['ChuaCircuit', 'ChuaCircuit', 'ChuaCircuit', 'ChuaCircuit', 'ChuaCircuit', 'ChuaCircuit', 'ChuaCircuit', 'ChuaCircuit', 'ChuaCircuit', 'ChuaCircuit', 'ChuaCircuit', 'ChuaCircuit'], '.../examples')
+       (['ChuaCircuit', 'ChuaCircuit', 'ChuaCircuit', 'ChuaCircuit', 'ChuaCircuit', 'ChuaCircuit', 'ChuaCircuit', 'ChuaCircuit', 'ChuaCircuit', 'ChuaCircuit', 'ChuaCircuit', 'ChuaCircuit'], '...examples')
 
     In "examples/run-sims2.mos", there are commands to run and save results
     from 12 simulation experiments.
@@ -749,7 +709,7 @@ class ParamDict(dict):
     modifiers, formatted for Modelica_
 
     Otherwise, this class is the same as :class:`dict`.  The underlying
-    structure is not nested or reformmated---only the informal representation
+    structure is not nested or reformatted---only the informal representation
     (:meth:`ParamDict.__str__`).
     """
     def __str__(self):
@@ -782,7 +742,7 @@ class ParamDict(dict):
 
            >>> d = ParamDict({'a': 1, 'b.c': array([2, 3]), 'b.d': False,
            ...                'b.e': '"hello"', 'b.f': None})
-           >>> print d
+           >>> print(d)
            (a=1, b(c={2, 3}, e="hello", d=false))
 
            # The formal representation (and the internal structure) is unaffected:
@@ -790,7 +750,7 @@ class ParamDict(dict):
            {'a': 1, 'b.c': array([2, 3]), 'b.f': None, 'b.e': '"hello"', 'b.d': False}
 
            # An empty dictionary prints as an empty string (not "()"):
-           print ParamDict({})
+           print(ParamDict({}))
 
         .. _Python: http://www.python.org/
         """
