@@ -2,6 +2,12 @@
 """Classes and methods to create a (limited) graphical user interface for
 ModelicaRes
 """
+__author__ = "Kevin Davies"
+__email__ = "kdavies4@gmail.com"
+__copyright__ = "Copyright 2012, Georgia Tech Research Corporation"
+__license__ = "BSD-compatible (see LICENSE.txt)"
+
+
 import wx
 
 from matplotlib import rcParams
